pub trait Error: CoreError { }Expand description
A trait for types that can be used to represent an error.
Particularly, this is a supertrait of the core library Error trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".