Crate fack_core

Crate fack_core 

Core error capability used by the fack facade.

This crate owns the blanket Error trait and no code generation logic.

Modules

error
A module for the Error trait and its implementations.
prelude
A module that re-exports the most commonly used types and traits in this crate.