pub trait Error: CoreError { }
A trait for types that can be used to represent an error.
Particularly, this is a supertrait of the core library Error trait.
Error
Blanket implementation of Error for types that are also core Errors.